"""
Main interface for mediastore-data service type definitions.

Usage::

    ```python
    from mypy_boto3_mediastore_data.type_defs import ItemTypeDef

    data: ItemTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import IO, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

import sys

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "ItemTypeDef",
    "DescribeObjectResponseTypeDef",
    "GetObjectResponseTypeDef",
    "ListItemsResponseTypeDef",
    "PaginatorConfigTypeDef",
    "PutObjectResponseTypeDef",
)

ItemTypeDef = TypedDict(
    "ItemTypeDef",
    {
        "Name": str,
        "Type": Literal["OBJECT", "FOLDER"],
        "ETag": str,
        "LastModified": datetime,
        "ContentType": str,
        "ContentLength": int,
    },
    total=False,
)

DescribeObjectResponseTypeDef = TypedDict(
    "DescribeObjectResponseTypeDef",
    {
        "ETag": str,
        "ContentType": str,
        "ContentLength": int,
        "CacheControl": str,
        "LastModified": datetime,
    },
    total=False,
)

_RequiredGetObjectResponseTypeDef = TypedDict(
    "_RequiredGetObjectResponseTypeDef", {"StatusCode": int}
)
_OptionalGetObjectResponseTypeDef = TypedDict(
    "_OptionalGetObjectResponseTypeDef",
    {
        "Body": IO[bytes],
        "CacheControl": str,
        "ContentRange": str,
        "ContentLength": int,
        "ContentType": str,
        "ETag": str,
        "LastModified": datetime,
    },
    total=False,
)

class GetObjectResponseTypeDef(
    _RequiredGetObjectResponseTypeDef, _OptionalGetObjectResponseTypeDef
):
    pass

ListItemsResponseTypeDef = TypedDict(
    "ListItemsResponseTypeDef", {"Items": List["ItemTypeDef"], "NextToken": str}, total=False
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

PutObjectResponseTypeDef = TypedDict(
    "PutObjectResponseTypeDef",
    {"ContentSHA256": str, "ETag": str, "StorageClass": Literal["TEMPORAL"]},
    total=False,
)



"""
Main interface for mediastore-data service.

Usage::

    ```python
    import boto3
    from mypy_boto3_mediastore_data import (
        Client,
        ListItemsPaginator,
        MediaStoreDataClient,
    )

    session = boto3.Session()

    client: MediaStoreDataClient = boto3.client("mediastore-data")
    session_client: MediaStoreDataClient = session.client("mediastore-data")

    list_items_paginator: ListItemsPaginator = client.get_paginator("list_items")
    ```
"""
from mypy_boto3_mediastore_data.client import MediaStoreDataClient
from mypy_boto3_mediastore_data.paginator import ListItemsPaginator

Client = MediaStoreDataClient


__all__ = ("Client", "ListItemsPaginator", "MediaStoreDataClient")



# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
"""
Main interface for mediastore-data service client paginators.

Usage::

    ```python
    import boto3

    from mypy_boto3_mediastore_data import MediaStoreDataClient
    from mypy_boto3_mediastore_data.paginator import (
        ListItemsPaginator,
    )

    client: MediaStoreDataClient = boto3.client("mediastore-data")

    list_items_paginator: ListItemsPaginator = client.get_paginator("list_items")
    ```
"""
from typing import Iterator

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_mediastore_data.type_defs import ListItemsResponseTypeDef, PaginatorConfigTypeDef

__all__ = ("ListItemsPaginator",)

class ListItemsPaginator(Boto3Paginator):
    """
    [Paginator.ListItems documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Paginator.ListItems)
    """

    def paginate(
        self, Path: str = None, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListItemsResponseTypeDef]:
        """
        [ListItems.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/mediastore-data.html#MediaStoreData.Paginator.ListItems.paginate)
        """
